@@ -7,7 +7,7 @@ from countergen.augmenter_loading import SimpleAugmenter, default_converter_path
 from countergen.data_augmentation import AugmentedDataset, augment_dataset
 from countergen.evaluation import evaluate_and_print
 from countergen.generative_models import get_huggingface_gpt_model_evaluator
-from countergen.misc import overwrite_fire_help_text
+from countergen.misc import _overwrite_fire_help_text
 from countergen.types import Augmenter
 
 
@@ -101,14 +101,19 @@ def evaluate(
         print("Done!")
 
 
-if __name__ == "__main__":
-    overwrite_fire_help_text()
+def run():
+    _overwrite_fire_help_text()
     fire.Fire(
         {
             "augment": augment,
             "evaluate": evaluate,
         },
     )
+
+
+if __name__ == "__main__":
+    run()
+
     # python -m countergen augment countergen\data\datasets\tiny-test.jsonl countergen\data\augdatasets\tiny-test.jsonl gender
     # python -m countergen augment countergen\data\datasets\twitter-sentiment.jsonl countergen\data\augdatasets\twitter-sentiment.jsonl gender
     # python -m countergen augment countergen\data\datasets\doublebind.jsonl countergen\data\augdatasets\doublebind.jsonl gender
